``pyramlson``
==================

.. image:: https://travis-ci.org/jenner/pyramlson.png?branch=master
   :target: https://travis-ci.org/jenner/pyramlson

Build JSON REST APIs with RAML_ and Pyramid_.

.. _RAML: http://raml.org/
.. _Pyramid: http://docs.pylonsproject.org/en/latest/docs/pyramid.html
